==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/hu.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU információ nem elérhető",
    "Load average" : "Terhelési átlag",
    "Last minute" : "Előző perc",
    "Memory info not available" : "A memória információ nem érhető el",
    "Total" : "Összes",
    "Current usage" : "Aktuális használat",
    "Users" : "Felhasználók",
    "Groups" : "Csoportok",
    "Links" : "Hivatkozások",
    "Mails" : "Levelek",
    "Federated sent" : "Küldött egyesítés",
    "Federated received" : "Fogadott egyesítés",
    "Talk conversations" : "Beszélgetések",
    "24 hours" : "24 óra",
    "1 hour" : "1 óra",
    "5 mins" : "5 perc",
    "Copy" : "Másolás",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
    "System" : "Rendszer",
    "Monitoring" : "Megfigyelés",
    "Monitoring app with useful server information" : "Monitorozó alkalmazás hasznos szerver információkkal",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Hasznos szerver információk szolgáltatása, mint a CPU terhelés, RAM foglaltság, felhasználók száma, stb.",
    "Operating System" : "Operációs rendszer",
    "CPU" : "CPU",
    "Memory" : "Memória",
    "Server time" : "Kiszolgáló idő",
    "Time Servers" : "Időkiszolgálók",
    "Load" : "Terhelés",
    "Disk" : "Lemez",
    "Mount" : "Csatolás",
    "Filesystem" : "Fájlrendszer",
    "Size" : "Méret",
    "Available" : "Elérhető",
    "Used" : "Használt",
    "You will get a notification once one of your disks is nearly full." : "Értesítést lesz küldve, ha az egyik lemez majdnem megtelt.",
    "Files:" : "Fájlok:",
    "Storages:" : "Tárhelyek:",
    "Free Space:" : "Szabad hely:",
    "Network" : "Hálózat",
    "Hostname" : "Hosztnév",
    "DNS" : "DNS",
    "Gateway" : "Átjáró",
    "Status" : "Állapot",
    "Speed" : "Sebesség",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktív felhasználók",
    "Total users:" : "Összes felhasználó:",
    "Shares" : "Megosztások",
    "PHP" : "PHP",
    "Version:" : "Verzió:",
    "Memory Limit:" : "Memória limit:",
    "Max Execution Time:" : "Maximális végrehajtási idő:",
    "Upload max size:" : "Maximális feltöltési méret:",
    "Database" : "Adatbázis:",
    "Type:" : "Típus:",
    "Size:" : "Méret:",
    "External monitoring tool" : "Külső monitorozó eszköz",
    "You can connect an external monitoring tool by using this end point:" : "Ennek a végpontnak a használatával külső monitorozó eszközt csatlakoztathatsz:",
    "Did you know?" : "Tudtad?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Az URL végéhez \"?format=json\" hozzáfűzésével az eredményt JSON formátumban kapod meg!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/hu.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU információ nem elérhető",
    "Load average" : "Terhelési átlag",
    "Last minute" : "Előző perc",
    "Memory info not available" : "A memória információ nem érhető el",
    "Total" : "Összes",
    "Current usage" : "Aktuális használat",
    "Users" : "Felhasználók",
    "Groups" : "Csoportok",
    "Links" : "Hivatkozások",
    "Mails" : "Levelek",
    "Federated sent" : "Küldött egyesítés",
    "Federated received" : "Fogadott egyesítés",
    "Talk conversations" : "Beszélgetések",
    "24 hours" : "24 óra",
    "1 hour" : "1 óra",
    "5 mins" : "5 perc",
    "Copy" : "Másolás",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
    "System" : "Rendszer",
    "Monitoring" : "Megfigyelés",
    "Monitoring app with useful server information" : "Monitorozó alkalmazás hasznos szerver információkkal",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Hasznos szerver információk szolgáltatása, mint a CPU terhelés, RAM foglaltság, felhasználók száma, stb.",
    "Operating System" : "Operációs rendszer",
    "CPU" : "CPU",
    "Memory" : "Memória",
    "Server time" : "Kiszolgáló idő",
    "Time Servers" : "Időkiszolgálók",
    "Load" : "Terhelés",
    "Disk" : "Lemez",
    "Mount" : "Csatolás",
    "Filesystem" : "Fájlrendszer",
    "Size" : "Méret",
    "Available" : "Elérhető",
    "Used" : "Használt",
    "You will get a notification once one of your disks is nearly full." : "Értesítést lesz küldve, ha az egyik lemez majdnem megtelt.",
    "Files:" : "Fájlok:",
    "Storages:" : "Tárhelyek:",
    "Free Space:" : "Szabad hely:",
    "Network" : "Hálózat",
    "Hostname" : "Hosztnév",
    "DNS" : "DNS",
    "Gateway" : "Átjáró",
    "Status" : "Állapot",
    "Speed" : "Sebesség",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktív felhasználók",
    "Total users:" : "Összes felhasználó:",
    "Shares" : "Megosztások",
    "PHP" : "PHP",
    "Version:" : "Verzió:",
    "Memory Limit:" : "Memória limit:",
    "Max Execution Time:" : "Maximális végrehajtási idő:",
    "Upload max size:" : "Maximális feltöltési méret:",
    "Database" : "Adatbázis:",
    "Type:" : "Típus:",
    "Size:" : "Méret:",
    "External monitoring tool" : "Külső monitorozó eszköz",
    "You can connect an external monitoring tool by using this end point:" : "Ennek a végpontnak a használatával külső monitorozó eszközt csatlakoztathatsz:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Az URL végéhez \"?format=json\" hozzáfűzésével az eredményt JSON formátumban kapod meg!",
    "Did you know?" : "Tudtad?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Az URL végéhez \"?format=json\" hozzáfűzésével az eredményt JSON formátumban kapod meg!"
},
"nplurals=2; plural=(n != 1);");
